@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::InternalTypes;
 
 BEGIN {
-    $WWW::Google::Contacts::InternalTypes::VERSION = '0.19';
+    $WWW::Google::Contacts::InternalTypes::VERSION = '0.20';
 }
 
 use MooseX::Types -declare => [
@@ -12,7 +12,7 @@ use MooseX::Types -declare => [
       )
 ];
 
-use MooseX::Types::Moose qw(Str Bool);
+use MooseX::Types::Moose qw(Str Bool HashRef);
 
 class_type Rel, { class => 'WWW::Google::Contacts::Type::Rel' };
 
@@ -36,4 +36,11 @@ class_type When, { class => 'WWW::Google::Contacts::Type::When' };
 coerce When, from Str, via {
     require WWW::Google::Contacts::Type::When;
     WWW::Google::Contacts::Type::When->new( start_time => $_ );
+}, from HashRef, via {
+    return undef unless defined $_->{startTime};
+    require WWW::Google::Contacts::Type::When;
+    WWW::Google::Contacts::Type::When->new(
+        start_time => $_->{startTime},
+        defined $_->{endTime} ? ( end_time => $_->{endTime} ) : (),
+    );
 };
